#ifndef POKEPLATINUM_UNK_0206A8DC_H
#define POKEPLATINUM_UNK_0206A8DC_H

#include "struct_decls/struct_020507E4_decl.h"

void sub_0206A92C(UnkStruct_020507E4 * param0);
BOOL sub_0206A938(UnkStruct_020507E4 * param0);
void sub_0206A944(UnkStruct_020507E4 * param0);
BOOL sub_0206A954(UnkStruct_020507E4 * param0);
void sub_0206A964(UnkStruct_020507E4 * param0);
void sub_0206A974(UnkStruct_020507E4 * param0);
BOOL sub_0206A984(UnkStruct_020507E4 * param0);
void sub_0206A994(UnkStruct_020507E4 * param0);
void sub_0206A9A4(UnkStruct_020507E4 * param0);
BOOL sub_0206A9B4(UnkStruct_020507E4 * param0);
void sub_0206A9C4(UnkStruct_020507E4 * param0);
void sub_0206A9D4(UnkStruct_020507E4 * param0);
BOOL sub_0206A9E4(UnkStruct_020507E4 * param0);
void sub_0206A9F4(UnkStruct_020507E4 * param0);
void sub_0206AA04(UnkStruct_020507E4 * param0);
void sub_0206AA14(UnkStruct_020507E4 * param0);
void sub_0206AA20(UnkStruct_020507E4 * param0);
void sub_0206AA30(UnkStruct_020507E4 * param0);
void sub_0206AA40(UnkStruct_020507E4 * param0);
void sub_0206AA50(UnkStruct_020507E4 * param0, int param1);
BOOL sub_0206AAA8(UnkStruct_020507E4 * param0, int param1);
BOOL sub_0206AB00(UnkStruct_020507E4 * param0, int param1);
u16 sub_0206AB68(UnkStruct_020507E4 * param0, int param1);
void sub_0206AD9C(UnkStruct_020507E4 * param0);
void sub_0206ADAC(UnkStruct_020507E4 * param0);
BOOL sub_0206ADBC(UnkStruct_020507E4 * param0);
BOOL sub_0206ADCC(UnkStruct_020507E4 * param0);
BOOL sub_0206ADDC(UnkStruct_020507E4 * param0);
BOOL sub_0206ADEC(UnkStruct_020507E4 * param0);
BOOL sub_0206ADFC(UnkStruct_020507E4 * param0);
void sub_0206AE0C(UnkStruct_020507E4 * param0);
void sub_0206AE1C(UnkStruct_020507E4 * param0);
BOOL sub_0206AE2C(UnkStruct_020507E4 * param0);
void sub_0206AE3C(UnkStruct_020507E4 * param0);
void sub_0206AE4C(UnkStruct_020507E4 * param0);
BOOL sub_0206AE5C(UnkStruct_020507E4 * param0);
void sub_0206AE6C(UnkStruct_020507E4 * param0);
void sub_0206AE7C(UnkStruct_020507E4 * param0);
BOOL sub_0206AE8C(UnkStruct_020507E4 * param0);
void sub_0206AE9C(UnkStruct_020507E4 * param0);
BOOL sub_0206AEAC(UnkStruct_020507E4 * param0, int param1);
void sub_0206AEBC(UnkStruct_020507E4 * param0);
void sub_0206AECC(UnkStruct_020507E4 * param0);
BOOL sub_0206AEDC(UnkStruct_020507E4 * param0);
void sub_0206AEEC(UnkStruct_020507E4 * param0);
void sub_0206AEFC(UnkStruct_020507E4 * param0);
BOOL sub_0206AF0C(UnkStruct_020507E4 * param0);
BOOL sub_0206AF1C(UnkStruct_020507E4 * param0, int param1);
BOOL sub_0206AF2C(UnkStruct_020507E4 * param0, int param1);
BOOL sub_0206AF3C(UnkStruct_020507E4 * param0, int param1, u32 param2);
void sub_0206AF5C(UnkStruct_020507E4 * param0);
BOOL sub_0206AF6C(UnkStruct_020507E4 * param0, int param1, int param2);
void sub_0206AF90(UnkStruct_020507E4 * param0);
void sub_0206AFA0(UnkStruct_020507E4 * param0);
BOOL sub_0206AFB0(UnkStruct_020507E4 * param0, int param1, int param2);
BOOL sub_0206AFC0(UnkStruct_020507E4 * param0, int param1);
BOOL sub_0206AFD0(UnkStruct_020507E4 * param0);

#endif // POKEPLATINUM_UNK_0206A8DC_H
